@@ -32,7 +32,7 @@ using namespace std;
 
 int main(int argc, char *argv[])
 {
-    version = 140110;
+    version = 150803;
 
     readArguments(argc, argv);
     int time1 = time(0);
@@ -603,6 +603,12 @@ void readArguments(int argc, char *argv[])
                 CORRECTP = true;
             }
 
+            // penalise gaps in NJ distances
+            else if (s=="-njgaps")
+            {
+                PENALISEGAPS = true;
+            }
+
             /********* technical: hirschberg, full probability **********/
 
             // "band" full probability (less memory)
@@ -667,6 +673,12 @@ void readArguments(int argc, char *argv[])
                 anchDropDist = atoi(string(argv[i]).substr(7).c_str());
             }
 
+            // ignore reverse anchors
+            else if (s=="-droprevanch")
+            {
+                dropRevAnch = true;
+            }
+
             // don't infer gaps caused by missing data
             else if (s=="-nopatchdata")
             {
